@@ -6,14 +6,8 @@ import pytest
 
 class TestLocalStorage:
 
-    @pytest.mark.parametrize(
-        "exception, value",
-        (
-            (WriteStorageError, int),
-            (WriteStorageError, str),
-        ),
-    )
-    def test_invalid_value(self, exception, value):
+    @pytest.mark.parametrize("value", (int, str,),)
+    def test_invalid_value(self, value):
         try:
             storage = LocalStorage()
             storage.setItem("x", value)
@@ -33,9 +27,34 @@ class TestLocalStorage:
         x = storage.getItem(key)
         assert x == value
 
+    def test_removeItemWithoutExcept(self):
+        try:
+            storage = LocalStorage()
+            storage.setItem("anything", "this")
+            storage.removeItem("anything")
+            storage.removeItem("anything")
+        except:
+            assert False
+        else:
+            assert True
+
     def test_removeItem(self):
         storage = LocalStorage()
         storage.setItem("x", "this")
         storage.removeItem("x")
         x = storage.getItem("x")
         assert x == None
+
+    def test_key(self):
+        storage = LocalStorage()
+        storage.setItem("x", "this")
+        assert storage.key(-1) is None
+        assert storage.key(storage.length) is None
+        assert None not in [storage.key(i) for i in range(storage.length)]
+
+    def test_clear(self):
+        storage = LocalStorage()
+        storage.setItem("x", "this")
+        assert storage.length > 0
+        storage.clear()
+        assert storage.length == 0
